/* 1x2 abgewinkelte Steckerleiste */
#macro PHW_2X1()
    object{PHW_GRND(2,1)}
#end

/********************************************************************************************************************************************
// Makro fuer LSG-Taster
// Benutzt Makro "IC_SMD_PIN" aus "ic.inc"
********************************************************************************************************************************************/
#macro SWITCH_PUSH_BUTTON_LSG(height)
// Makro fuer LSG-Grundkoerper (Quader mit abgerundeten senkrechten Kanten)
// Erstellt von Oliver Saal (osaal@gmx.de) 22.09.2003
// size_x = Laenge
// size_z = Breite
// height = Hoehe
// r      = Radius der Rundung
#macro SWITCH_PUSH_BUTTON_LSG_BOX(size_x,size_z,height,r)
union
{
    cylinder {<0,0,0><0,height,0> r translate<size_x/2-r,0,size_z/2-r>}
    cylinder {<0,0,0><0,height,0> r translate<size_x/2-r,0,-(size_z/2-r)>}
    cylinder {<0,0,0><0,height,0> r translate<-(size_x/2-r),0,size_z/2-r>}
    cylinder {<0,0,0><0,height,0> r translate<-(size_x/2-r),0,-(size_z/2-r)>}
    box {<-size_x/2,0,-size_z/2+r><size_x/2,height,size_z/2-r>}
    box {<-size_x/2+r,0,-size_z/2><size_z/2-r,height,size_z/2>}
}
#end

#macro SWITCH_PUSH_BUTTON_LSG_SIDE()
difference 
{
    union 
    {
	prism {0,0.2,7,<-3,0>,<3,0>,<3,-0.2>,<1.6,-1.6>,<-1.6,-1.6>,<-3,-0.2>,<-3,0> rotate<-90,0,0> translate<0,0,0.2>}
	cylinder {<-3,0,0>,<3,0,0>,0.2}
    }
    box {<-3.1,0,-0.2>,<3.1,-0.2,0>}
    prism {-1,1,7,<0,0>,<0.1,0>,<0.1,-1.2>,<-0.3,-1.2>,<-0.3,0.3>,<0,0.3>,<0,0> rotate<0,90,90>}
    translate<0,0,3> 
}
#end

union
{
    // Body
    union
    {
	object {SWITCH_PUSH_BUTTON_LSG_BOX(6,6,1.8,0.2)}
	box {<-1.05,0.9,-3.3><1.05,0.6,-3>} 
	box {<-1.05,0.9,3.3><1.05,0.6,3>}
    }

    // Cover
    union 
    {
	box {<-3,0,-3>,<3,0.2,3>} 
	object {SWITCH_PUSH_BUTTON_LSG_SIDE() rotate<0,180,0>}
	object {SWITCH_PUSH_BUTTON_LSG_SIDE()}
	texture{col_silver}
	translate<0,1.8,0> 
    }


    // Switch
    union 
    {
	cylinder {<0,2,0><0,height-0.2,0> 1.5 }
	torus {1.3, 0.2 translate<0,height-0.2,0>}
	cylinder {<0, height-0.2,0><0, height,0>,1.3}
    }

    // Pins
    object {IC_SMD_PIN(0.6,1.0,0.7,0.3) translate<3,0,2.25>}
    object {IC_SMD_PIN(0.6,1.0,0.7,0.3) translate<3,0,-2.25>}
    object {IC_SMD_PIN(0.6,1.0,0.7,0.3) rotate<0,180,0> translate<-3,0,-2.25>}
    object {IC_SMD_PIN(0.6,1.0,0.7,0.3) rotate<0,180,0> translate<-3,0,2.25>}

    pigment{Gray30}
}
#end

// LSG 2.5mm
#macro SWITCH_PUSH_BUTTON_LSG25()
object{SWITCH_PUSH_BUTTON_LSG(2.5)}
#end
// LSG 3.1mm
#macro SWITCH_PUSH_BUTTON_LSG31()
object{SWITCH_PUSH_BUTTON_LSG(3.1)}
#end

#macro CONNECTOR_FLACHSTECKER()
difference 
{
    union 
    {
	prism 
	{
	    -0.4,0.4,14,
	    <-3.1,2.2>,<-3.1,-2.5>,<-2.1,-2.5>,<-1.9,0>,<1.9,0>,<2.1,-2.5>,<3.1,-2.5>,
	    <3.1,2.2>,<0.3,5>,<-10,5>,<-10.4,4.6>,<-10.4,2.6>,<-10,2.2>,<-3.1,2.2>
	}

	cylinder{<2.6,0.5,-2.5><2.6,-0.5,-2.5>0.5}
	cylinder{<-2.6,0.5,-2.5><-2.6,-0.5,-2.5>0.5}
    }

    cylinder{<-8,0.6,3.6><-8,-0.6,3.6>0.7}

    rotate<0,90,90>

    texture{col_silver}
}
#end

#macro SPC_CERAMIC_OSCILLATOR_CSTCC(value)
#local round = 0.4;
union
{
    // Cover
    union 
    {
	box {<-(3.3-round),(1.55-round),-1.05><(3.3-round),0.5,1.05>}
	box {<-3.3,(1.55-round),-(1.05-round)><3.3,0.5,(1.05-round)>}
	box {<-(3.3-round),1.55,-(1.05-round)><(3.3-round),0.5,(1.05-round)>}
	cylinder {<-(3.3-round),(1.55-round),(1.05-round)><-(3.3-round),(1.55-round),-(1.05-round)>,round}
	cylinder {<(3.3-round),(1.55-round),(1.05-round)><(3.3-round),(1.55-round),-(1.05-round)>,round} 
	cylinder {<-(3.3-round),(1.55-round),(1.05-round)><(3.3-round),(1.55-round),(1.05-round)>,round} 
	cylinder {<-(3.3-round),(1.55-round),-(1.05-round)><(3.3-round),(1.55-round),-(1.05-round)>,round} 
	sphere {<(3.3-round),(1.55-round),(1.05-round)>,round} 
	sphere {<(3.3-round),(1.55-round),-(1.05-round)>,round} 
	sphere {<-(3.3-round),(1.55-round),(1.05-round)>,round} 
	sphere {<-(3.3-round),(1.55-round),-(1.05-round)>,round} 
	cylinder {<-(3.3-round),(1.55-round),(1.05-round)><-(3.3-round),0.5,(1.05-round)>,round} 
	cylinder {<(3.3-round),(1.55-round),(1.05-round)><(3.3-round),0.5,(1.05-round)>,round} 
	cylinder {<-(3.3-round),(1.55-round),-(1.05-round)><-(3.3-round),0.5,-(1.05-round)>,round} 
	cylinder {<(3.3-round),(1.55-round),-(1.05-round)><(3.3-round),0.5,-(1.05-round)>,round} 

	text {ttf besch_font value 0, 0 pigment{Black} rotate<90,0,0> translate<-2.7,1.5501,-0.3>}

	texture{col_silver}
    }

    difference 
    {
	union 
	{
	    box {<-3.5,0,-1.5><3.5,0.5,1.5>} 
	    union 
	    {
		box {<-0.7,0.5001,-1.4><0.7,0.5,1.4>} 
		box {<-0.6,0.5001,-1.4><0.6,0.5,1.4> translate x*2.5}
		box {<-0.6,0.5001,-1.4><0.6,0.5,1.4> translate x*(-2.5)}
		box {<-0.7,-0.0001,-1.4><0.7,0,1.4>} 
		box {<-0.6,-0.0001,-1.4><0.6,0,1.4> translate x*2.5}
		box {<-0.6,-0.0001,-1.4><0.6,0,1.4> translate x*(-2.5)}
		texture{col_gold}
	    }
	}

	union 
	{
	    cylinder {<0,0.6,-1.5><0,-0.1,-1.5>,0.3} 
	    cylinder {<2.5,0.6,1.5><2.5,-0.1,1.5>,0.3} 
	    cylinder {<-2.5,0.6,1.5><-2.5,-0.1,1.5>,0.3} 
	    cylinder {<2.5,0.6,-1.5><2.5,-0.1,-1.5>,0.3} 
	    cylinder {<-2.5,0.6,-1.5><-2.5,-0.1,-1.5>,0.3} 
	    cylinder {<0,0.6,1.5><0,-0.1,1.5>,0.3} 
	    texture{col_gold}
	}
	pigment{Gray90}
    }
}
#end

#macro SPC_RELAY_BISTABIL_DS2E_L2(value)

#macro SPC_RELAY_BISTABIL_DS2E_L2_PIN()
prism {0,0.25,6,<-0.25,1>,<0.25,1>,<0.25,-3.05>,<0,-3.3>,<-0.25,-3.05>,<-0.25,1> rotate<-90,0,0>}
#end

#macro SPC_RELAY_BISTABIL_DS2E_L2_PINPAIR()
union 
{
    object {SPC_RELAY_BISTABIL_DS2E_L2_PIN() translate<0,0,-3.81>} 
    object {SPC_RELAY_BISTABIL_DS2E_L2_PIN() translate<0,0,3.81>}
}
#end

#local round = 0.5;
union 
{
    // Cover
    difference 
    {
	// Box
	union 
	{
	    box {<-(10-round),(10-round),-5><(10-round),0,5>}
	    box {<-10,(10-round),-(5-round)><10,0.5,(5-round)>}
	    box {<-(10-round),10,-(5-round)><(10-round),0.5,(5-round)>}
	    cylinder {<-(10-round),(10-round),(5-round)><-(10-round),(10-round),-(5-round)>,round}
	    cylinder {<(10-round),(10-round),(5-round)><(10-round),(10-round),-(5-round)>,round} 
	    cylinder {<-(10-round),(10-round),(5-round)><(10-round),(10-round),(5-round)>,round} 
	    cylinder {<-(10-round),(10-round),-(5-round)><(10-round),(10-round),-(5-round)>,round} 
	    sphere {<(10-round),(10-round),(5-round)>,round} 
	    sphere {<(10-round),(10-round),-(5-round)>,round} 
	    sphere {<-(10-round),(10-round),(5-round)>,round} 
	    sphere {<-(10-round),(10-round),-(5-round)>,round} 
	    cylinder {<-(10-round),(10-round),(5-round)><-(10-round),0,(5-round)>,round} 
	    cylinder {<(10-round),(10-round),(5-round)><(10-round),0,(5-round)>,round} 
	    cylinder {<-(10-round),(10-round),-(5-round)><-(10-round),0,-(5-round)>,round} 
	    cylinder {<(10-round),(10-round),-(5-round)><(10-round),0,-(5-round)>,round} 

	    text {ttf besch_font value 0, 0 pigment{Black} scale<3,3,1> rotate<90,0,0> translate<-9,10.001,-1>}
	}

	box {<1.1,0,-1><0,0.5,1> translate<9,9.6,0>} 
	box {<9.4,-0.1,4.4><-9.4,1,-4.4>} 
	box {<10.1,-0.1,3.55><8.55,0.65,-3.55>} 
	box {<-8.55,-0.1,3.55><-10.1,0.65,-3.55>} 
	cylinder {<-10.1,0,3.55><10.1,0,3.55>,0.65} 
	cylinder {<-10.1,0,-3.55><10.1,0,-3.55>,0.65} 
	box {<8.55,-0.1,5.1><-8.55,0.65,3.55>} 
	box {<8.55,-0.1,-5.1><-8.55,0.65,-3.55>} 
	cylinder {<8.55,0,-5.1><8.55,0,5.1>,0.65} 
	cylinder {<-8.55,0,-5.1><-8.55,0,5.1>,0.65} 

	translate x*1.27

	pigment{Blue}
    }

    // Pins
    union 
    {
	object {SPC_RELAY_BISTABIL_DS2E_L2_PINPAIR()}
	object {SPC_RELAY_BISTABIL_DS2E_L2_PINPAIR() translate x*(-5.08)} 
	object {SPC_RELAY_BISTABIL_DS2E_L2_PINPAIR() translate x*(-7.62)} 
	object {SPC_RELAY_BISTABIL_DS2E_L2_PINPAIR() translate x*5.08} 
	object {SPC_RELAY_BISTABIL_DS2E_L2_PINPAIR() translate x*10.16} 

	texture{col_gold}
    }
}
#end
